===============================
Ybosspy
===============================

.. image:: https://badge.fury.io/py/yboss.png
    :target: http://badge.fury.io/py/yboss

.. image:: https://travis-ci.org/inovatho/yboss.png?branch=master
        :target: https://travis-ci.org/inovatho/yboss

.. image:: https://pypip.in/d/yboss/badge.png
        :target: https://crate.io/packages/yboss?version=latest


Python wrapper for Yahoo Boss API

* Free software: BSD license
* Documentation: http://yboss.rtfd.org.

Features
--------

- Authenticate and search in YBoss API
